import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:zppickerview/picker_common.dart';
import 'package:zppickerview/picker_title.dart';


class OptionView extends StatefulWidget {

  OptionView({
    Key key,
    this.onCancel,
    this.onChange,
    this.onConfirm,
    this.firstItems,
  }): assert(
  firstItems != null,
  'A non-null List<String> must be provided to a OptionView widget.',
  )  , super(key: key);

  final VoidCallback onCancel;
  final OptionValueCallback onChange,onConfirm;

  final List<dynamic> firstItems;

  @override
  State<StatefulWidget> createState() {
    return _OptionViewState();
  }
}

class _OptionViewState extends State<OptionView> {


  int _selectedFirst = 0;


  void _valueChanged(value) {


    _selectedFirst = value;

  }

  void _onCancel() {
    if(null != widget.onCancel) {
      widget.onCancel();
    }
    Navigator.pop(context);
  }

  void _onConfirm() {
    if(null != widget.onConfirm) {
      widget.onConfirm(_selectedFirst, 0 , 0);
    }
    Navigator.pop(context);
  }


  @override
  Widget build(BuildContext context) {
    return _renderContent();
  }


  Widget _renderContent() {
    return  GestureDetector(
      child: Material(
          color: Colors.transparent, child: _buildChildView(context)),
    );
  }

  Widget _buildChildView(BuildContext context) {
    return Column(children: <Widget>[
      PickerTitleView(onCancel: _onCancel, onConfirm: _onConfirm,),
      getPickerView()
    ]);
  }

  Widget getPickerContetn() {
    return Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          getPickerView()
        ]);
  }

  Widget getPickerView() {
    return Expanded(
      flex: 1,
      child: Container(
        padding: EdgeInsets.all(8.0),
        height:216,
        decoration: BoxDecoration(color: Colors.white),
        child: CupertinoPicker.builder(
          backgroundColor: Colors.white,
          itemExtent: 44,
          childCount: widget.firstItems.length ?? 0,
          onSelectedItemChanged: _valueChanged,
          itemBuilder: (context, index) =>
              getPickerViewCell('${widget.firstItems[index]}'),
        ),
      ),
    );
  }

  Widget getPickerViewCell(String value) {
    return Container(
      height: 44,
      alignment: Alignment.center,
      child: Text(
        value,
        style: TextStyle(

        )
      ),
    );
  }




}