library zppickerview;
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:zppickerview/picker_common.dart';
import 'option_view.dart';




class ZPickerView {



  static void show(
      BuildContext context,
      List<String>  firstItems,
      {
        List<String>  secondItems,
        List<String>  thirdItems,
        OptionValueCallback onChange,
        VoidCallback onCancel,
        OptionValueCallback onConfirm,

      }) {
    Navigator.push(context, _PickerRoute(
      firstItems: firstItems,
      onCancel: onCancel,
      onConfirm: onConfirm,
      onChange: onChange,
    ));
  }


}


class _PickerRoute<T> extends PopupRoute<T> {

  _PickerRoute({
    this.firstItems,
    this.onCancel,
    this.onChange,
    this.onConfirm,
    RouteSettings settings,
  }) : super(settings: settings);

  final Duration _duration = Duration(milliseconds: 200);

  final VoidCallback onCancel;
  final OptionValueCallback onChange,onConfirm;
  final List<dynamic> firstItems;


  AnimationController _animationController;

  //遮罩颜色
  @override
  Color get barrierColor => Colors.black54;

  ///Whether you can dismiss this route by tapping the modal barrier.
  /// 点击遮罩消除
  @override
  bool get barrierDismissible => true;

  @override
  String get barrierLabel => null;

  @override
  AnimationController createAnimationController() {
    assert(_animationController == null);
    _animationController =
        BottomSheet.createAnimationController(navigator.overlay);
    return _animationController;
  }


  @override
  Widget buildPage(BuildContext context, Animation<double> animation, Animation<double> secondaryAnimation) {

    double height = 216.0;

    Widget bottomSheet = new MediaQuery.removePadding(
      context: context,
      removeTop: true,
      child: _PickerContent(route: this,),
    );
    return bottomSheet;
  }

  @override
  Duration get transitionDuration => _duration;


}



/// 分别显示optionView ， dateView
class _PickerContent extends StatelessWidget {

  final _PickerRoute route;
//  final double _pickerHeight;
  _PickerContent({Key key, this.route});

  @override
  Widget build(BuildContext context) {

    ///optionView
    Widget pickerWidget = OptionView(
      firstItems: route.firstItems,
      onConfirm: route.onConfirm,
      onCancel: route.onCancel,
      onChange: route.onChange,
    );

    return new GestureDetector(
      child: new AnimatedBuilder(
        animation: route.animation,
        builder: (BuildContext context, Widget child) {
          return new ClipRect(
            child: new CustomSingleChildLayout(
              delegate: new _BottomPickerLayout(route.animation.value,
                  contentHeight: 260),
              child: pickerWidget,
            ),
          );
        },
      ),
    );
  }


}


class _BottomPickerLayout extends SingleChildLayoutDelegate {
  _BottomPickerLayout(this.progress, {this.contentHeight});

  final double progress;
  final double contentHeight;

  @override
  BoxConstraints getConstraintsForChild(BoxConstraints constraints) {
    return new BoxConstraints(
      minWidth: constraints.maxWidth,
      maxWidth: constraints.maxWidth,
      minHeight: 0.0,
      maxHeight: contentHeight,
    );
  }

  @override
  Offset getPositionForChild(Size size, Size childSize) {
    double height = size.height - childSize.height * progress;
    return new Offset(0.0, height);
  }

  @override
  bool shouldRelayout(_BottomPickerLayout oldDelegate) {
    return progress != oldDelegate.progress;
  }
}



